================
PETSc for Python
================

:Author:       Lisandro Dalcin
:Contact:      dalcinl@gmail.com


Online Documentation
--------------------

+ `User Manual (HTML)`_ (generated with Sphinx_).
+ `User Manual (PDF)`_  (generated with Sphinx_).
+ `API Reference`_      (generated with Sphinx_).

.. _User Manual (HTML): html/index.html
.. _User Manual (PDF):  petsc4py.pdf
.. _API Reference:      html/reference/index.html

.. _Sphinx:    https://www.sphinx-doc.org/
.. _Epydoc:    https://epydoc.sourceforge.net/


Discussion and Support
----------------------

+ Mailing Lists: petsc-users@mcs.anl.gov, petsc-dev@mcs.anl.gov


Downloads and Development
-------------------------

+ Issue Tracker:  https://gitlab.com/petsc/petsc/-/issues
+ Git Repository: https://gitlab.com/petsc/petsc.git
+ The source code is in ``src/binding/petsc4py``
+ Previous source releases: https://pypi.org/project/petsc4py/

Citations
---------

If PETSc for Python been significant to a project that leads to an
academic publication, please acknowledge that fact by citing the
project.

* L. Dalcin, P. Kler, R. Paz, and A. Cosimo,
  *Parallel Distributed Computing using Python*,
  Advances in Water Resources, 34(9):1124-1139, 2011.
  http://dx.doi.org/10.1016/j.advwatres.2011.04.013

* S. Balay, S. Abhyankar, M. Adams, S. Benson, J. Brown,
  P. Brune, K. Buschelman, E. Constantinescu, L. Dalcin, A. Dener,
  V. Eijkhout, J. Faibussowitsch, W. Gropp, V. Hapla, T. Isaac, P. Jolivet,
  D. Karpeyev, D. Kaushik, M. Knepley, F. Kong, S. Kruger,
  D. May, L. Curfman McInnes, R. Mills, L. Mitchell, T. Munson,
  J. Roman, K. Rupp, P. Sanan, J Sarich, B. Smith, H. Suh,
  S. Zampini, H. Zhang, and H. Zhang, J. Zhang,
  *PETSc/TAO Users Manual*, ANL-21/39 - Revision 3.23, 2025.
  https://petsc.org/release/docs/manual


Acknowledgments
---------------

This project was partially supported by the
Extreme Computing Research Center (ECRC),
Division of Computer, Electrical, and
Mathematical Sciences & Engineering (CEMSE),
King Abdullah University of Science and Technology (KAUST).
